# OrthogonalCamera

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**view_to_world_scale** | **float** |  | 
**camera_direction** | [**Direction**](Direction.md) |  | 
**camera_up_vector** | [**Direction**](Direction.md) |  | 
**camera_view_point** | [**Point**](Point.md) |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


